<template>
  <!-- 搜索 -->
  <ContentWrap>
    <el-form
      class="-mb-15px"
      :model="queryParams"
      ref="queryFormRef"
      :inline="true"
      label-width="68px"
    >
      <el-form-item label="测点编码" prop="pointNo">
        <el-input
          v-model="queryParams.pointNo"
          placeholder="请输入测点编码"
          clearable
          @keyup.enter="handleQuery"
          class="!w-200px"
        />
      </el-form-item>
      <el-form-item label="测点名称" prop="pointName">
        <el-input
          v-model="queryParams.pointName"
          placeholder="请输入测点名称"
          clearable
          @keyup.enter="handleQuery"
          class="!w-200px"
        />
      </el-form-item>
      <el-form-item label="测点Tag" prop="tagNo">
        <el-input
          v-model="queryParams.tagNo"
          placeholder="请输入测点Tag"
          clearable
          @keyup.enter="handleQuery"
          class="!w-200px"
        />
      </el-form-item>
      <el-form-item>
        <el-button @click="handleQuery">
          <Icon icon="ep:search" class="mr-5px" />
          搜索
        </el-button>
        <el-button @click="resetQuery">
          <Icon icon="ep:refresh" class="mr-5px" />
          重置
        </el-button>
        <el-button
          type="primary"
          plain
          @click="openForm('create')"
          v-hasPermi="['data:point:create']"
        >
          <Icon icon="ep:plus" class="mr-5px" />
          新增
        </el-button>
        <el-button
          type="warning"
          plain
          @click="handleImport"
          v-hasPermi="['data:point:import']"
        >
          <Icon icon="ep:upload" /> 导入
        </el-button>
        <el-button
          type="success"
          plain
          @click="handleExport"
          :loading="exportLoading"
          v-hasPermi="['data:point:export']"
        >
          <Icon icon="ep:download" />导出
        </el-button>
        <el-button
          type="success"
          plain
          @click="enable"
          v-hasPermi="['data:point:update']"
        >启用
        </el-button>
        <el-button
          type="danger"
          plain
          @click="disable"
          v-hasPermi="['data:point:update']"
        >禁用
        </el-button>
      </el-form-item>
    </el-form>
  </ContentWrap>

  <!-- 列表 -->
  <ContentWrap>
    <el-table border stripe v-loading="loading" :data="list" @selection-change="selectionChangeHandle">
      <el-table-column type="selection" header-align="center" align="center" width="50"/>
      <el-table-column fixed label="测点编码" header-align="center" align="left" min-width="130" prop="pointNo" />
      <el-table-column label="测点名称" header-align="center" align="left" min-width="220" prop="pointName" />
      <el-table-column label="测点类型" align="center" prop="pointType" width="100">
        <template #default="scope">
          <dict-tag :type="DICT_TYPE.DATA_POINT_TYPE" :value="scope.row.pointType" />
        </template>
      </el-table-column>
      <el-table-column label="数据类型" align="center" prop="dataType" width="100">
        <template #default="scope">
          <dict-tag :type="DICT_TYPE.POINT_DATA_TYPE" :value="scope.row.dataType" />
        </template>
      </el-table-column>
      <el-table-column label="值类型" align="center" prop="valueType" width="120">
        <template #default="scope">
          <dict-tag :type="DICT_TYPE.MEASURE_VALUE_TYPE" :value="scope.row.valueType" />
        </template>
      </el-table-column>
      <el-table-column label="测量单位" align="center" prop="unit" width="80"/>
      <el-table-column label="单位转换" align="center" prop="unittransfactor" />
      <el-table-column label="默认值" align="center" prop="defaultValue" width="100"/>
      <el-table-column label="采集频率" align="center" prop="minfreqid" width="100"/>
      <el-table-column label="数据源类型" align="center" prop="sourceType" min-width="100"/>
      <el-table-column label="数据源名称" align="center" prop="sourceName" min-width="100"/>
      <el-table-column label="测点Tag" header-align="center" align="left" prop="tagNo" min-width="150"/>
      <el-table-column label="是否启用" align="center" prop="isEnable" width="85">
        <template #default="scope">
          <el-tag v-if="scope.row.isEnable === 1" size="small">是</el-tag>
          <el-tag v-else size="small" type="danger">否</el-tag>
        </template>
      </el-table-column>

      <el-table-column label="操作" align="center" min-width="130" fixed="right" width="120">
        <template #default="scope">
          <el-button
            link
            size="mini"
            type="primary"
            @click="openForm('update', scope.row.id)"
            v-hasPermi="['data:point:update']"
          >
            编辑
          </el-button>
          <el-button link size="mini" type="primary" @click="chartHandle(scope.row)">数据</el-button>
          <el-button
            link
            size="mini"
            type="danger"
            @click="handleDelete(scope.row.id)"
            v-hasPermi="['data:point:delete']"
          >
            删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>
    <!-- 分页 -->
    <Pagination
      :total="total"
      v-model:page="queryParams.pageNo"
      v-model:limit="queryParams.pageSize"
      @pagination="getList"
    />
  </ContentWrap>

  <!-- 表单弹窗：添加/修改 -->
  <DaPointForm ref="formRef" @success="getList" />

  <DaPointChart ref="chartView" />

  <!-- 用户导入对话框 -->
  <PointImportForm ref="importFormRef" @success="getList" />
</template>
<script lang="ts" setup>
import * as DaPoint from '@/api/data/da/point'
import {ref, reactive} from "vue";
import download from "@/utils/download";
import {DICT_TYPE, getDictOptions} from "@/utils/dict";
import DaPointForm from './DaPointForm.vue'
import DaPointChart from './DaPointChart.vue'
import * as UserApi from "@/api/system/user";
import PointImportForm from './PointImportForm.vue'

defineOptions({name: 'DataPoint'})

  const message = useMessage() // 消息弹窗
  const {t} = useI18n() // 国际化

  const loading = ref(true) // 列表的加载中
  const total = ref(0) // 列表的总页数
  const list = ref([]) // 列表的数据
  const queryParams = reactive({
    pageNo: 1,
    pageSize: 10,
    pointNo: undefined,
    pointName: undefined,
    tagNo: undefined,
  })
  const queryFormRef = ref() // 搜索的表单

  /** 查询列表 */
  const getList = async () => {
    loading.value = true
    try {
      const page = await DaPoint.getDaPointPage(queryParams)
      list.value = page.list
      total.value = page.total
    } finally {
      loading.value = false
    }
  }

  /** 搜索按钮操作 */
  const handleQuery = () => {
    queryParams.pageNo = 1
    getList()
  }

  /** 查看数据操作 */
  const chartView  = ref()
  const chartHandle = (raw: object) => {
    chartView.value.open(raw)
  }

  /** 重置按钮操作 */
  const resetQuery = () => {
    queryFormRef.value.resetFields()
    handleQuery()
  }

  /** 添加/修改操作 */
  const formRef = ref()
  const openForm = (type: string, id?: number) => {
    formRef.value.open(type, id)
  }

  /** 删除按钮操作 */
  const handleDelete = async (id: number) => {
    try {
      // 删除的二次确认
      await message.delConfirm()
      // 发起删除
      await DaPoint.deleteDaPoint(id)
      message.success(t('common.delSuccess'))
      // 刷新列表
      await getList()
    } catch {
    }
  }
  /** 测点导入 */
  const importFormRef = ref()
  const handleImport = () => {
    importFormRef.value.open()
  }

  /** 导出按钮操作 */
  const exportLoading = ref(false)
  const handleExport = async () => {
    try {
      // 导出的二次确认
      await message.exportConfirm()
      // 发起导出
      exportLoading.value = true
      const data = await DaPoint.exportDaPoint(queryParams)
      download.excel(data, '测点列表.xlsx')
    } catch {
    } finally {
      exportLoading.value = false
    }
  }

  let dataListSelections = reactive([])
  // 多选
  function selectionChangeHandle (val) {
    dataListSelections = val
  }
  // 启用
  async function enable() {
    let ids = dataListSelections.map(item => {
      return item.id
    })
    // 启用的二次确认
    await message.enableConfirm(ids)

    await DaPoint.enable(ids)
    message.success(t('common.enableSuccess'))
    await getList()
  }
  // 禁用
  async function disable(){
    let ids = dataListSelections.map(item => {
      return item.id
    })
    // 启用的二次确认
    await message.disableConfirm(ids,)

    await DaPoint.disable(ids)
    message.success(t('common.disableSuccess'))
    await getList()
  }

  /** 初始化 **/
  onMounted(async () => {
    await getList()
  })
</script>
